mocks

package
v0.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AzureServiceClient

type AzureServiceClient struct {
	mock.Mock
}

AzureServiceClient is an autogenerated mock type for the AzureServiceClient type

func NewAzureServiceClient

func NewAzureServiceClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *AzureServiceClient

NewAzureServiceClient creates a new instance of AzureServiceClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*AzureServiceClient) AttachRelAzureDataSource

AttachRelAzureDataSource provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) DeleteAzure

func (_m *AzureServiceClient) DeleteAzure(ctx context.Context, in *azure.DeleteAzureRequest, opts ...grpc.CallOption) (*azure.Empty, error)

DeleteAzure provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) DetachRelAzureDataSource

func (_m *AzureServiceClient) DetachRelAzureDataSource(ctx context.Context, in *azure.DetachRelAzureDataSourceRequest, opts ...grpc.CallOption) (*azure.Empty, error)

DetachRelAzureDataSource provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) GetAzure

GetAzure provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) GetRelAzureDataSource

GetRelAzureDataSource provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) InvokeScanAll

func (_m *AzureServiceClient) InvokeScanAll(ctx context.Context, in *azure.InvokeScanAllRequest, opts ...grpc.CallOption) (*azure.Empty, error)

InvokeScanAll provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) InvokeScanAzure

func (_m *AzureServiceClient) InvokeScanAzure(ctx context.Context, in *azure.InvokeScanAzureRequest, opts ...grpc.CallOption) (*azure.Empty, error)

InvokeScanAzure provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) ListAzure

ListAzure provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) ListAzureDataSource

ListAzureDataSource provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) ListRelAzureDataSource

ListRelAzureDataSource provides a mock function with given fields: ctx, in, opts

func (*AzureServiceClient) PutAzure

PutAzure provides a mock function with given fields: ctx, in, opts

type AzureServiceServer

type AzureServiceServer struct {
	mock.Mock
}

AzureServiceServer is an autogenerated mock type for the AzureServiceServer type

func NewAzureServiceServer

func NewAzureServiceServer(t interface {
	mock.TestingT
	Cleanup(func())
}) *AzureServiceServer

NewAzureServiceServer creates a new instance of AzureServiceServer. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*AzureServiceServer) AttachRelAzureDataSource

AttachRelAzureDataSource provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) DeleteAzure

func (_m *AzureServiceServer) DeleteAzure(_a0 context.Context, _a1 *azure.DeleteAzureRequest) (*azure.Empty, error)

DeleteAzure provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) DetachRelAzureDataSource

func (_m *AzureServiceServer) DetachRelAzureDataSource(_a0 context.Context, _a1 *azure.DetachRelAzureDataSourceRequest) (*azure.Empty, error)

DetachRelAzureDataSource provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) GetAzure

GetAzure provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) GetRelAzureDataSource

GetRelAzureDataSource provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) InvokeScanAll

func (_m *AzureServiceServer) InvokeScanAll(_a0 context.Context, _a1 *azure.InvokeScanAllRequest) (*azure.Empty, error)

InvokeScanAll provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) InvokeScanAzure

func (_m *AzureServiceServer) InvokeScanAzure(_a0 context.Context, _a1 *azure.InvokeScanAzureRequest) (*azure.Empty, error)

InvokeScanAzure provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) ListAzure

ListAzure provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) ListAzureDataSource

ListAzureDataSource provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) ListRelAzureDataSource

ListRelAzureDataSource provides a mock function with given fields: _a0, _a1

func (*AzureServiceServer) PutAzure

PutAzure provides a mock function with given fields: _a0, _a1

type GoogleServiceClient

type GoogleServiceClient struct {
	mock.Mock
}

GoogleServiceClient is an autogenerated mock type for the GoogleServiceClient type

func NewGoogleServiceClient

func NewGoogleServiceClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *GoogleServiceClient

NewGoogleServiceClient creates a new instance of GoogleServiceClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*GoogleServiceClient) AttachGCPDataSource

AttachGCPDataSource provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) DeleteGCP

DeleteGCP provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) DetachGCPDataSource

func (_m *GoogleServiceClient) DetachGCPDataSource(ctx context.Context, in *google.DetachGCPDataSourceRequest, opts ...grpc.CallOption) (*google.Empty, error)

DetachGCPDataSource provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) GetGCP

GetGCP provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) GetGCPDataSource

GetGCPDataSource provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) InvokeScanAll

InvokeScanAll provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) InvokeScanGCP

InvokeScanGCP provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) ListGCP

ListGCP provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) ListGCPDataSource

ListGCPDataSource provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) ListGoogleDataSource

ListGoogleDataSource provides a mock function with given fields: ctx, in, opts

func (*GoogleServiceClient) PutGCP

PutGCP provides a mock function with given fields: ctx, in, opts

type GoogleServiceServer

type GoogleServiceServer struct {
	mock.Mock
}

GoogleServiceServer is an autogenerated mock type for the GoogleServiceServer type

func NewGoogleServiceServer

func NewGoogleServiceServer(t interface {
	mock.TestingT
	Cleanup(func())
}) *GoogleServiceServer

NewGoogleServiceServer creates a new instance of GoogleServiceServer. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*GoogleServiceServer) AttachGCPDataSource

AttachGCPDataSource provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) DeleteGCP

DeleteGCP provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) DetachGCPDataSource

func (_m *GoogleServiceServer) DetachGCPDataSource(_a0 context.Context, _a1 *google.DetachGCPDataSourceRequest) (*google.Empty, error)

DetachGCPDataSource provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) GetGCP

GetGCP provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) GetGCPDataSource

GetGCPDataSource provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) InvokeScanAll

InvokeScanAll provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) InvokeScanGCP

InvokeScanGCP provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) ListGCP

ListGCP provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) ListGCPDataSource

ListGCPDataSource provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) ListGoogleDataSource

ListGoogleDataSource provides a mock function with given fields: _a0, _a1

func (*GoogleServiceServer) PutGCP

PutGCP provides a mock function with given fields: _a0, _a1

Jump to