Documentation
¶
Index ¶
- type AzureServiceClient
- func (_m *AzureServiceClient) AttachRelAzureDataSource(ctx context.Context, in *azure.AttachRelAzureDataSourceRequest, ...) (*azure.AttachRelAzureDataSourceResponse, error)
- func (_m *AzureServiceClient) DeleteAzure(ctx context.Context, in *azure.DeleteAzureRequest, opts ...grpc.CallOption) (*azure.Empty, error)
- func (_m *AzureServiceClient) DetachRelAzureDataSource(ctx context.Context, in *azure.DetachRelAzureDataSourceRequest, ...) (*azure.Empty, error)
- func (_m *AzureServiceClient) GetAzure(ctx context.Context, in *azure.GetAzureRequest, opts ...grpc.CallOption) (*azure.GetAzureResponse, error)
- func (_m *AzureServiceClient) GetRelAzureDataSource(ctx context.Context, in *azure.GetRelAzureDataSourceRequest, ...) (*azure.GetRelAzureDataSourceResponse, error)
- func (_m *AzureServiceClient) InvokeScanAll(ctx context.Context, in *azure.InvokeScanAllRequest, opts ...grpc.CallOption) (*azure.Empty, error)
- func (_m *AzureServiceClient) InvokeScanAzure(ctx context.Context, in *azure.InvokeScanAzureRequest, opts ...grpc.CallOption) (*azure.Empty, error)
- func (_m *AzureServiceClient) ListAzure(ctx context.Context, in *azure.ListAzureRequest, opts ...grpc.CallOption) (*azure.ListAzureResponse, error)
- func (_m *AzureServiceClient) ListAzureDataSource(ctx context.Context, in *azure.ListAzureDataSourceRequest, ...) (*azure.ListAzureDataSourceResponse, error)
- func (_m *AzureServiceClient) ListRelAzureDataSource(ctx context.Context, in *azure.ListRelAzureDataSourceRequest, ...) (*azure.ListRelAzureDataSourceResponse, error)
- func (_m *AzureServiceClient) PutAzure(ctx context.Context, in *azure.PutAzureRequest, opts ...grpc.CallOption) (*azure.PutAzureResponse, error)
- type AzureServiceServer
- func (_m *AzureServiceServer) AttachRelAzureDataSource(_a0 context.Context, _a1 *azure.AttachRelAzureDataSourceRequest) (*azure.AttachRelAzureDataSourceResponse, error)
- func (_m *AzureServiceServer) DeleteAzure(_a0 context.Context, _a1 *azure.DeleteAzureRequest) (*azure.Empty, error)
- func (_m *AzureServiceServer) DetachRelAzureDataSource(_a0 context.Context, _a1 *azure.DetachRelAzureDataSourceRequest) (*azure.Empty, error)
- func (_m *AzureServiceServer) GetAzure(_a0 context.Context, _a1 *azure.GetAzureRequest) (*azure.GetAzureResponse, error)
- func (_m *AzureServiceServer) GetRelAzureDataSource(_a0 context.Context, _a1 *azure.GetRelAzureDataSourceRequest) (*azure.GetRelAzureDataSourceResponse, error)
- func (_m *AzureServiceServer) InvokeScanAll(_a0 context.Context, _a1 *azure.InvokeScanAllRequest) (*azure.Empty, error)
- func (_m *AzureServiceServer) InvokeScanAzure(_a0 context.Context, _a1 *azure.InvokeScanAzureRequest) (*azure.Empty, error)
- func (_m *AzureServiceServer) ListAzure(_a0 context.Context, _a1 *azure.ListAzureRequest) (*azure.ListAzureResponse, error)
- func (_m *AzureServiceServer) ListAzureDataSource(_a0 context.Context, _a1 *azure.ListAzureDataSourceRequest) (*azure.ListAzureDataSourceResponse, error)
- func (_m *AzureServiceServer) ListRelAzureDataSource(_a0 context.Context, _a1 *azure.ListRelAzureDataSourceRequest) (*azure.ListRelAzureDataSourceResponse, error)
- func (_m *AzureServiceServer) PutAzure(_a0 context.Context, _a1 *azure.PutAzureRequest) (*azure.PutAzureResponse, error)
- type GoogleServiceClient
- func (_m *GoogleServiceClient) AttachGCPDataSource(ctx context.Context, in *google.AttachGCPDataSourceRequest, ...) (*google.AttachGCPDataSourceResponse, error)
- func (_m *GoogleServiceClient) DeleteGCP(ctx context.Context, in *google.DeleteGCPRequest, opts ...grpc.CallOption) (*google.Empty, error)
- func (_m *GoogleServiceClient) DetachGCPDataSource(ctx context.Context, in *google.DetachGCPDataSourceRequest, ...) (*google.Empty, error)
- func (_m *GoogleServiceClient) GetGCP(ctx context.Context, in *google.GetGCPRequest, opts ...grpc.CallOption) (*google.GetGCPResponse, error)
- func (_m *GoogleServiceClient) GetGCPDataSource(ctx context.Context, in *google.GetGCPDataSourceRequest, ...) (*google.GetGCPDataSourceResponse, error)
- func (_m *GoogleServiceClient) InvokeScanAll(ctx context.Context, in *google.InvokeScanAllRequest, opts ...grpc.CallOption) (*google.Empty, error)
- func (_m *GoogleServiceClient) InvokeScanGCP(ctx context.Context, in *google.InvokeScanGCPRequest, opts ...grpc.CallOption) (*google.Empty, error)
- func (_m *GoogleServiceClient) ListGCP(ctx context.Context, in *google.ListGCPRequest, opts ...grpc.CallOption) (*google.ListGCPResponse, error)
- func (_m *GoogleServiceClient) ListGCPDataSource(ctx context.Context, in *google.ListGCPDataSourceRequest, ...) (*google.ListGCPDataSourceResponse, error)
- func (_m *GoogleServiceClient) ListGoogleDataSource(ctx context.Context, in *google.ListGoogleDataSourceRequest, ...) (*google.ListGoogleDataSourceResponse, error)
- func (_m *GoogleServiceClient) PutGCP(ctx context.Context, in *google.PutGCPRequest, opts ...grpc.CallOption) (*google.PutGCPResponse, error)
- type GoogleServiceServer
- func (_m *GoogleServiceServer) AttachGCPDataSource(_a0 context.Context, _a1 *google.AttachGCPDataSourceRequest) (*google.AttachGCPDataSourceResponse, error)
- func (_m *GoogleServiceServer) DeleteGCP(_a0 context.Context, _a1 *google.DeleteGCPRequest) (*google.Empty, error)
- func (_m *GoogleServiceServer) DetachGCPDataSource(_a0 context.Context, _a1 *google.DetachGCPDataSourceRequest) (*google.Empty, error)
- func (_m *GoogleServiceServer) GetGCP(_a0 context.Context, _a1 *google.GetGCPRequest) (*google.GetGCPResponse, error)
- func (_m *GoogleServiceServer) GetGCPDataSource(_a0 context.Context, _a1 *google.GetGCPDataSourceRequest) (*google.GetGCPDataSourceResponse, error)
- func (_m *GoogleServiceServer) InvokeScanAll(_a0 context.Context, _a1 *google.InvokeScanAllRequest) (*google.Empty, error)
- func (_m *GoogleServiceServer) InvokeScanGCP(_a0 context.Context, _a1 *google.InvokeScanGCPRequest) (*google.Empty, error)
- func (_m *GoogleServiceServer) ListGCP(_a0 context.Context, _a1 *google.ListGCPRequest) (*google.ListGCPResponse, error)
- func (_m *GoogleServiceServer) ListGCPDataSource(_a0 context.Context, _a1 *google.ListGCPDataSourceRequest) (*google.ListGCPDataSourceResponse, error)
- func (_m *GoogleServiceServer) ListGoogleDataSource(_a0 context.Context, _a1 *google.ListGoogleDataSourceRequest) (*google.ListGoogleDataSourceResponse, error)
- func (_m *GoogleServiceServer) PutGCP(_a0 context.Context, _a1 *google.PutGCPRequest) (*google.PutGCPResponse, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AzureServiceClient ¶
AzureServiceClient is an autogenerated mock type for the AzureServiceClient type
func NewAzureServiceClient ¶
func NewAzureServiceClient(t interface {
mock.TestingT
Cleanup(func())
}) *AzureServiceClient
NewAzureServiceClient creates a new instance of AzureServiceClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*AzureServiceClient) AttachRelAzureDataSource ¶
func (_m *AzureServiceClient) AttachRelAzureDataSource(ctx context.Context, in *azure.AttachRelAzureDataSourceRequest, opts ...grpc.CallOption) (*azure.AttachRelAzureDataSourceResponse, error)
AttachRelAzureDataSource provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) DeleteAzure ¶
func (_m *AzureServiceClient) DeleteAzure(ctx context.Context, in *azure.DeleteAzureRequest, opts ...grpc.CallOption) (*azure.Empty, error)
DeleteAzure provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) DetachRelAzureDataSource ¶
func (_m *AzureServiceClient) DetachRelAzureDataSource(ctx context.Context, in *azure.DetachRelAzureDataSourceRequest, opts ...grpc.CallOption) (*azure.Empty, error)
DetachRelAzureDataSource provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) GetAzure ¶
func (_m *AzureServiceClient) GetAzure(ctx context.Context, in *azure.GetAzureRequest, opts ...grpc.CallOption) (*azure.GetAzureResponse, error)
GetAzure provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) GetRelAzureDataSource ¶
func (_m *AzureServiceClient) GetRelAzureDataSource(ctx context.Context, in *azure.GetRelAzureDataSourceRequest, opts ...grpc.CallOption) (*azure.GetRelAzureDataSourceResponse, error)
GetRelAzureDataSource provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) InvokeScanAll ¶
func (_m *AzureServiceClient) InvokeScanAll(ctx context.Context, in *azure.InvokeScanAllRequest, opts ...grpc.CallOption) (*azure.Empty, error)
InvokeScanAll provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) InvokeScanAzure ¶
func (_m *AzureServiceClient) InvokeScanAzure(ctx context.Context, in *azure.InvokeScanAzureRequest, opts ...grpc.CallOption) (*azure.Empty, error)
InvokeScanAzure provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) ListAzure ¶
func (_m *AzureServiceClient) ListAzure(ctx context.Context, in *azure.ListAzureRequest, opts ...grpc.CallOption) (*azure.ListAzureResponse, error)
ListAzure provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) ListAzureDataSource ¶
func (_m *AzureServiceClient) ListAzureDataSource(ctx context.Context, in *azure.ListAzureDataSourceRequest, opts ...grpc.CallOption) (*azure.ListAzureDataSourceResponse, error)
ListAzureDataSource provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) ListRelAzureDataSource ¶
func (_m *AzureServiceClient) ListRelAzureDataSource(ctx context.Context, in *azure.ListRelAzureDataSourceRequest, opts ...grpc.CallOption) (*azure.ListRelAzureDataSourceResponse, error)
ListRelAzureDataSource provides a mock function with given fields: ctx, in, opts
func (*AzureServiceClient) PutAzure ¶
func (_m *AzureServiceClient) PutAzure(ctx context.Context, in *azure.PutAzureRequest, opts ...grpc.CallOption) (*azure.PutAzureResponse, error)
PutAzure provides a mock function with given fields: ctx, in, opts
type AzureServiceServer ¶
AzureServiceServer is an autogenerated mock type for the AzureServiceServer type
func NewAzureServiceServer ¶
func NewAzureServiceServer(t interface {
mock.TestingT
Cleanup(func())
}) *AzureServiceServer
NewAzureServiceServer creates a new instance of AzureServiceServer. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*AzureServiceServer) AttachRelAzureDataSource ¶
func (_m *AzureServiceServer) AttachRelAzureDataSource(_a0 context.Context, _a1 *azure.AttachRelAzureDataSourceRequest) (*azure.AttachRelAzureDataSourceResponse, error)
AttachRelAzureDataSource provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) DeleteAzure ¶
func (_m *AzureServiceServer) DeleteAzure(_a0 context.Context, _a1 *azure.DeleteAzureRequest) (*azure.Empty, error)
DeleteAzure provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) DetachRelAzureDataSource ¶
func (_m *AzureServiceServer) DetachRelAzureDataSource(_a0 context.Context, _a1 *azure.DetachRelAzureDataSourceRequest) (*azure.Empty, error)
DetachRelAzureDataSource provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) GetAzure ¶
func (_m *AzureServiceServer) GetAzure(_a0 context.Context, _a1 *azure.GetAzureRequest) (*azure.GetAzureResponse, error)
GetAzure provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) GetRelAzureDataSource ¶
func (_m *AzureServiceServer) GetRelAzureDataSource(_a0 context.Context, _a1 *azure.GetRelAzureDataSourceRequest) (*azure.GetRelAzureDataSourceResponse, error)
GetRelAzureDataSource provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) InvokeScanAll ¶
func (_m *AzureServiceServer) InvokeScanAll(_a0 context.Context, _a1 *azure.InvokeScanAllRequest) (*azure.Empty, error)
InvokeScanAll provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) InvokeScanAzure ¶
func (_m *AzureServiceServer) InvokeScanAzure(_a0 context.Context, _a1 *azure.InvokeScanAzureRequest) (*azure.Empty, error)
InvokeScanAzure provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) ListAzure ¶
func (_m *AzureServiceServer) ListAzure(_a0 context.Context, _a1 *azure.ListAzureRequest) (*azure.ListAzureResponse, error)
ListAzure provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) ListAzureDataSource ¶
func (_m *AzureServiceServer) ListAzureDataSource(_a0 context.Context, _a1 *azure.ListAzureDataSourceRequest) (*azure.ListAzureDataSourceResponse, error)
ListAzureDataSource provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) ListRelAzureDataSource ¶
func (_m *AzureServiceServer) ListRelAzureDataSource(_a0 context.Context, _a1 *azure.ListRelAzureDataSourceRequest) (*azure.ListRelAzureDataSourceResponse, error)
ListRelAzureDataSource provides a mock function with given fields: _a0, _a1
func (*AzureServiceServer) PutAzure ¶
func (_m *AzureServiceServer) PutAzure(_a0 context.Context, _a1 *azure.PutAzureRequest) (*azure.PutAzureResponse, error)
PutAzure provides a mock function with given fields: _a0, _a1
type GoogleServiceClient ¶
GoogleServiceClient is an autogenerated mock type for the GoogleServiceClient type
func NewGoogleServiceClient ¶
func NewGoogleServiceClient(t interface {
mock.TestingT
Cleanup(func())
}) *GoogleServiceClient
NewGoogleServiceClient creates a new instance of GoogleServiceClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*GoogleServiceClient) AttachGCPDataSource ¶
func (_m *GoogleServiceClient) AttachGCPDataSource(ctx context.Context, in *google.AttachGCPDataSourceRequest, opts ...grpc.CallOption) (*google.AttachGCPDataSourceResponse, error)
AttachGCPDataSource provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) DeleteGCP ¶
func (_m *GoogleServiceClient) DeleteGCP(ctx context.Context, in *google.DeleteGCPRequest, opts ...grpc.CallOption) (*google.Empty, error)
DeleteGCP provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) DetachGCPDataSource ¶
func (_m *GoogleServiceClient) DetachGCPDataSource(ctx context.Context, in *google.DetachGCPDataSourceRequest, opts ...grpc.CallOption) (*google.Empty, error)
DetachGCPDataSource provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) GetGCP ¶
func (_m *GoogleServiceClient) GetGCP(ctx context.Context, in *google.GetGCPRequest, opts ...grpc.CallOption) (*google.GetGCPResponse, error)
GetGCP provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) GetGCPDataSource ¶
func (_m *GoogleServiceClient) GetGCPDataSource(ctx context.Context, in *google.GetGCPDataSourceRequest, opts ...grpc.CallOption) (*google.GetGCPDataSourceResponse, error)
GetGCPDataSource provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) InvokeScanAll ¶
func (_m *GoogleServiceClient) InvokeScanAll(ctx context.Context, in *google.InvokeScanAllRequest, opts ...grpc.CallOption) (*google.Empty, error)
InvokeScanAll provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) InvokeScanGCP ¶
func (_m *GoogleServiceClient) InvokeScanGCP(ctx context.Context, in *google.InvokeScanGCPRequest, opts ...grpc.CallOption) (*google.Empty, error)
InvokeScanGCP provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) ListGCP ¶
func (_m *GoogleServiceClient) ListGCP(ctx context.Context, in *google.ListGCPRequest, opts ...grpc.CallOption) (*google.ListGCPResponse, error)
ListGCP provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) ListGCPDataSource ¶
func (_m *GoogleServiceClient) ListGCPDataSource(ctx context.Context, in *google.ListGCPDataSourceRequest, opts ...grpc.CallOption) (*google.ListGCPDataSourceResponse, error)
ListGCPDataSource provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) ListGoogleDataSource ¶
func (_m *GoogleServiceClient) ListGoogleDataSource(ctx context.Context, in *google.ListGoogleDataSourceRequest, opts ...grpc.CallOption) (*google.ListGoogleDataSourceResponse, error)
ListGoogleDataSource provides a mock function with given fields: ctx, in, opts
func (*GoogleServiceClient) PutGCP ¶
func (_m *GoogleServiceClient) PutGCP(ctx context.Context, in *google.PutGCPRequest, opts ...grpc.CallOption) (*google.PutGCPResponse, error)
PutGCP provides a mock function with given fields: ctx, in, opts
type GoogleServiceServer ¶
GoogleServiceServer is an autogenerated mock type for the GoogleServiceServer type
func NewGoogleServiceServer ¶
func NewGoogleServiceServer(t interface {
mock.TestingT
Cleanup(func())
}) *GoogleServiceServer
NewGoogleServiceServer creates a new instance of GoogleServiceServer. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*GoogleServiceServer) AttachGCPDataSource ¶
func (_m *GoogleServiceServer) AttachGCPDataSource(_a0 context.Context, _a1 *google.AttachGCPDataSourceRequest) (*google.AttachGCPDataSourceResponse, error)
AttachGCPDataSource provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) DeleteGCP ¶
func (_m *GoogleServiceServer) DeleteGCP(_a0 context.Context, _a1 *google.DeleteGCPRequest) (*google.Empty, error)
DeleteGCP provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) DetachGCPDataSource ¶
func (_m *GoogleServiceServer) DetachGCPDataSource(_a0 context.Context, _a1 *google.DetachGCPDataSourceRequest) (*google.Empty, error)
DetachGCPDataSource provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) GetGCP ¶
func (_m *GoogleServiceServer) GetGCP(_a0 context.Context, _a1 *google.GetGCPRequest) (*google.GetGCPResponse, error)
GetGCP provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) GetGCPDataSource ¶
func (_m *GoogleServiceServer) GetGCPDataSource(_a0 context.Context, _a1 *google.GetGCPDataSourceRequest) (*google.GetGCPDataSourceResponse, error)
GetGCPDataSource provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) InvokeScanAll ¶
func (_m *GoogleServiceServer) InvokeScanAll(_a0 context.Context, _a1 *google.InvokeScanAllRequest) (*google.Empty, error)
InvokeScanAll provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) InvokeScanGCP ¶
func (_m *GoogleServiceServer) InvokeScanGCP(_a0 context.Context, _a1 *google.InvokeScanGCPRequest) (*google.Empty, error)
InvokeScanGCP provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) ListGCP ¶
func (_m *GoogleServiceServer) ListGCP(_a0 context.Context, _a1 *google.ListGCPRequest) (*google.ListGCPResponse, error)
ListGCP provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) ListGCPDataSource ¶
func (_m *GoogleServiceServer) ListGCPDataSource(_a0 context.Context, _a1 *google.ListGCPDataSourceRequest) (*google.ListGCPDataSourceResponse, error)
ListGCPDataSource provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) ListGoogleDataSource ¶
func (_m *GoogleServiceServer) ListGoogleDataSource(_a0 context.Context, _a1 *google.ListGoogleDataSourceRequest) (*google.ListGoogleDataSourceResponse, error)
ListGoogleDataSource provides a mock function with given fields: _a0, _a1
func (*GoogleServiceServer) PutGCP ¶
func (_m *GoogleServiceServer) PutGCP(_a0 context.Context, _a1 *google.PutGCPRequest) (*google.PutGCPResponse, error)
PutGCP provides a mock function with given fields: _a0, _a1